pub enum Frame {
Bytes(Vec<u8>),
Eof(bool),
ExitCode(i32),
MissedBytes(u64),
Error(String),
StolenBy(String),
}Variants
Bytes(Vec<u8>)
Eof(bool)
The child closed this stream (EOF). Terminal frame for the attachment; the daemon will close the stream connection after.
ExitCode(i32)
The child has exited; the int payload is the exit code. Terminal frame.
MissedBytes(u64)
Error(String)
StolenBy(String)
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn merge(
field: &mut Option<Frame>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Frame>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.