pub enum Frame {
Input(Vec<u8>),
Resize(PtyResize),
Interrupt(bool),
Detach(bool),
}Variants
Input(Vec<u8>)
Raw bytes to write to the PTY master (stdin).
Resize(PtyResize)
Terminal resize; daemon applies via portable-pty resize.
Interrupt(bool)
Send SIGINT / CTRL_C_EVENT to the child process group.
Detach(bool)
Clean detach. Daemon keeps the session alive but releases this attachment.
Implementations
Sourceimpl Frame
impl Frame
Sourcepub fn merge(
field: &mut Option<Frame>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Frame>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.