pub struct AttachPipeStreamRequest {
pub session_id: String,
pub stream: i32,
pub steal: bool,
}Fields
session_id: Stringstream: i32steal: boolIf true, evict any currently-attached client on this stream.
Implementations
Sourceimpl AttachPipeStreamRequest
impl AttachPipeStreamRequest
Sourcepub fn stream(&self) -> PipeStreamKind
pub fn stream(&self) -> PipeStreamKind
Returns the enum value of stream, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stream(&mut self, value: PipeStreamKind)
pub fn set_stream(&mut self, value: PipeStreamKind)
Sets stream to the provided enum value.