pub struct DaemonRequest {Show 14 fields
pub id: u64,
pub type: i32,
pub protocol_version: u32,
pub client_name: String,
pub register: Option<RegisterRequest>,
pub unregister: Option<UnregisterRequest>,
pub list_active: Option<ListActiveRequest>,
pub list_by_originator: Option<ListByOriginatorRequest>,
pub get_process_tree: Option<GetProcessTreeRequest>,
pub kill_zombies: Option<KillZombiesRequest>,
pub kill_tree: Option<KillTreeRequest>,
pub ping: Option<PingRequest>,
pub shutdown: Option<ShutdownRequest>,
pub status: Option<StatusRequest>,
}Fields
id: u64type: i32protocol_version: u32client_name: Stringregister: Option<RegisterRequest>Payload fields — field numbers match RequestType enum values.
unregister: Option<UnregisterRequest>list_active: Option<ListActiveRequest>list_by_originator: Option<ListByOriginatorRequest>get_process_tree: Option<GetProcessTreeRequest>kill_zombies: Option<KillZombiesRequest>kill_tree: Option<KillTreeRequest>ping: Option<PingRequest>shutdown: Option<ShutdownRequest>status: Option<StatusRequest>Implementations
Sourceimpl DaemonRequest
impl DaemonRequest
Sourcepub fn type(&self) -> RequestType
pub fn type(&self) -> RequestType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: RequestType)
pub fn set_type(&mut self, value: RequestType)
Sets type to the provided enum value.