DaemonResponse

Struct DaemonResponse 

pub struct DaemonResponse {
Show 39 fields pub request_id: u64, pub code: i32, pub message: String, pub register: Option<RegisterResponse>, pub unregister: Option<UnregisterResponse>, pub spawn_daemon: Option<SpawnDaemonResponse>, pub list_active: Option<ListActiveResponse>, pub list_by_originator: Option<ListByOriginatorResponse>, pub get_process_tree: Option<GetProcessTreeResponse>, pub kill_zombies: Option<KillZombiesResponse>, pub kill_tree: Option<KillTreeResponse>, pub ping: Option<PingResponse>, pub shutdown: Option<ShutdownResponse>, pub status: Option<StatusResponse>, pub service_start: Option<ServiceStartResponse>, pub service_stop: Option<ServiceStopResponse>, pub service_restart: Option<ServiceRestartResponse>, pub service_delete: Option<ServiceDeleteResponse>, pub service_list: Option<ServiceListResponse>, pub service_describe: Option<ServiceDescribeResponse>, pub service_logs: Option<ServiceLogsResponse>, pub service_flush: Option<ServiceFlushResponse>, pub service_save: Option<ServiceSaveResponse>, pub service_resurrect: Option<ServiceResurrectResponse>, pub spawn_pty_session: Option<SpawnPtySessionResponse>, pub attach_pty_session: Option<AttachPtySessionResponse>, pub detach_pty_session: Option<DetachPtySessionResponse>, pub list_pty_sessions: Option<ListPtySessionsResponse>, pub terminate_pty_session: Option<TerminatePtySessionResponse>, pub spawn_pipe_session: Option<SpawnPipeSessionResponse>, pub attach_pipe_stream: Option<AttachPipeStreamResponse>, pub detach_pipe_stream: Option<DetachPipeStreamResponse>, pub list_pipe_sessions: Option<ListPipeSessionsResponse>, pub terminate_pipe_session: Option<TerminatePipeSessionResponse>, pub write_pipe_stdin: Option<WritePipeStdinResponse>, pub get_session_backlog: Option<GetSessionBacklogResponse>, pub purge_exited_sessions: Option<PurgeExitedSessionsResponse>, pub bulk_terminate_sessions: Option<BulkTerminateSessionsResponse>, pub resize_pty_session: Option<ResizePtySessionResponse>,
}

Fields

request_id: u64code: i32message: Stringregister: Option<RegisterResponse>

Payload fields — field numbers match RequestType enum values.

unregister: Option<UnregisterResponse>spawn_daemon: Option<SpawnDaemonResponse>list_active: Option<ListActiveResponse>list_by_originator: Option<ListByOriginatorResponse>get_process_tree: Option<GetProcessTreeResponse>kill_zombies: Option<KillZombiesResponse>kill_tree: Option<KillTreeResponse>ping: Option<PingResponse>shutdown: Option<ShutdownResponse>status: Option<StatusResponse>service_start: Option<ServiceStartResponse>service_stop: Option<ServiceStopResponse>service_restart: Option<ServiceRestartResponse>service_delete: Option<ServiceDeleteResponse>service_list: Option<ServiceListResponse>service_describe: Option<ServiceDescribeResponse>service_logs: Option<ServiceLogsResponse>service_flush: Option<ServiceFlushResponse>service_save: Option<ServiceSaveResponse>service_resurrect: Option<ServiceResurrectResponse>spawn_pty_session: Option<SpawnPtySessionResponse>attach_pty_session: Option<AttachPtySessionResponse>detach_pty_session: Option<DetachPtySessionResponse>list_pty_sessions: Option<ListPtySessionsResponse>terminate_pty_session: Option<TerminatePtySessionResponse>spawn_pipe_session: Option<SpawnPipeSessionResponse>attach_pipe_stream: Option<AttachPipeStreamResponse>detach_pipe_stream: Option<DetachPipeStreamResponse>list_pipe_sessions: Option<ListPipeSessionsResponse>terminate_pipe_session: Option<TerminatePipeSessionResponse>write_pipe_stdin: Option<WritePipeStdinResponse>get_session_backlog: Option<GetSessionBacklogResponse>purge_exited_sessions: Option<PurgeExitedSessionsResponse>bulk_terminate_sessions: Option<BulkTerminateSessionsResponse>resize_pty_session: Option<ResizePtySessionResponse>

Implementations

Source

impl DaemonResponse

pub fn code(&self) -> StatusCode

Returns the enum value of code, or the default if the field is set to an invalid enum value.

pub fn set_code(&mut self, value: StatusCode)

Sets code to the provided enum value.