pub struct TrackedProcess {
pub pid: u32,
pub created_at: f64,
pub kind: String,
pub command: String,
pub cwd: String,
pub originator: String,
pub containment: String,
pub registered_at: f64,
pub uptime_seconds: f64,
pub parent_alive: bool,
pub state: i32,
pub last_validated_at: f64,
}Fields
pid: u32created_at: f64kind: Stringcommand: Stringcwd: Stringoriginator: Stringcontainment: Stringregistered_at: f64uptime_seconds: f64parent_alive: boolstate: i32last_validated_at: f64Implementations
Sourceimpl TrackedProcess
impl TrackedProcess
Sourcepub fn state(&self) -> ProcessState
pub fn state(&self) -> ProcessState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ProcessState)
pub fn set_state(&mut self, value: ProcessState)
Sets state to the provided enum value.