pub struct DaemonRequest {Show 40 fields
pub id: u64,
pub type: i32,
pub protocol_version: u32,
pub client_name: String,
pub register: Option<RegisterRequest>,
pub unregister: Option<UnregisterRequest>,
pub spawn_daemon: Option<SpawnDaemonRequest>,
pub list_active: Option<ListActiveRequest>,
pub list_by_originator: Option<ListByOriginatorRequest>,
pub get_process_tree: Option<GetProcessTreeRequest>,
pub kill_zombies: Option<KillZombiesRequest>,
pub kill_tree: Option<KillTreeRequest>,
pub ping: Option<PingRequest>,
pub shutdown: Option<ShutdownRequest>,
pub status: Option<StatusRequest>,
pub service_start: Option<ServiceStartRequest>,
pub service_stop: Option<ServiceStopRequest>,
pub service_restart: Option<ServiceRestartRequest>,
pub service_delete: Option<ServiceDeleteRequest>,
pub service_list: Option<ServiceListRequest>,
pub service_describe: Option<ServiceDescribeRequest>,
pub service_logs: Option<ServiceLogsRequest>,
pub service_flush: Option<ServiceFlushRequest>,
pub service_save: Option<ServiceSaveRequest>,
pub service_resurrect: Option<ServiceResurrectRequest>,
pub spawn_pty_session: Option<SpawnPtySessionRequest>,
pub attach_pty_session: Option<AttachPtySessionRequest>,
pub detach_pty_session: Option<DetachPtySessionRequest>,
pub list_pty_sessions: Option<ListPtySessionsRequest>,
pub terminate_pty_session: Option<TerminatePtySessionRequest>,
pub spawn_pipe_session: Option<SpawnPipeSessionRequest>,
pub attach_pipe_stream: Option<AttachPipeStreamRequest>,
pub detach_pipe_stream: Option<DetachPipeStreamRequest>,
pub list_pipe_sessions: Option<ListPipeSessionsRequest>,
pub terminate_pipe_session: Option<TerminatePipeSessionRequest>,
pub write_pipe_stdin: Option<WritePipeStdinRequest>,
pub get_session_backlog: Option<GetSessionBacklogRequest>,
pub purge_exited_sessions: Option<PurgeExitedSessionsRequest>,
pub bulk_terminate_sessions: Option<BulkTerminateSessionsRequest>,
pub resize_pty_session: Option<ResizePtySessionRequest>,
}Fields
id: u64type: i32protocol_version: u32client_name: Stringregister: Option<RegisterRequest>Payload fields — field numbers match RequestType enum values.
unregister: Option<UnregisterRequest>spawn_daemon: Option<SpawnDaemonRequest>list_active: Option<ListActiveRequest>list_by_originator: Option<ListByOriginatorRequest>get_process_tree: Option<GetProcessTreeRequest>kill_zombies: Option<KillZombiesRequest>kill_tree: Option<KillTreeRequest>ping: Option<PingRequest>shutdown: Option<ShutdownRequest>status: Option<StatusRequest>service_start: Option<ServiceStartRequest>service_stop: Option<ServiceStopRequest>service_restart: Option<ServiceRestartRequest>service_delete: Option<ServiceDeleteRequest>service_list: Option<ServiceListRequest>service_describe: Option<ServiceDescribeRequest>service_logs: Option<ServiceLogsRequest>service_flush: Option<ServiceFlushRequest>service_save: Option<ServiceSaveRequest>service_resurrect: Option<ServiceResurrectRequest>spawn_pty_session: Option<SpawnPtySessionRequest>attach_pty_session: Option<AttachPtySessionRequest>detach_pty_session: Option<DetachPtySessionRequest>list_pty_sessions: Option<ListPtySessionsRequest>terminate_pty_session: Option<TerminatePtySessionRequest>spawn_pipe_session: Option<SpawnPipeSessionRequest>attach_pipe_stream: Option<AttachPipeStreamRequest>detach_pipe_stream: Option<DetachPipeStreamRequest>list_pipe_sessions: Option<ListPipeSessionsRequest>terminate_pipe_session: Option<TerminatePipeSessionRequest>write_pipe_stdin: Option<WritePipeStdinRequest>get_session_backlog: Option<GetSessionBacklogRequest>purge_exited_sessions: Option<PurgeExitedSessionsRequest>bulk_terminate_sessions: Option<BulkTerminateSessionsRequest>resize_pty_session: Option<ResizePtySessionRequest>Implementations
Sourceimpl DaemonRequest
impl DaemonRequest
Sourcepub fn type(&self) -> RequestType
pub fn type(&self) -> RequestType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: RequestType)
pub fn set_type(&mut self, value: RequestType)
Sets type to the provided enum value.