pub struct DaemonResponse {Show 13 fields
pub request_id: u64,
pub code: i32,
pub message: String,
pub register: Option<RegisterResponse>,
pub unregister: Option<UnregisterResponse>,
pub list_active: Option<ListActiveResponse>,
pub list_by_originator: Option<ListByOriginatorResponse>,
pub get_process_tree: Option<GetProcessTreeResponse>,
pub kill_zombies: Option<KillZombiesResponse>,
pub kill_tree: Option<KillTreeResponse>,
pub ping: Option<PingResponse>,
pub shutdown: Option<ShutdownResponse>,
pub status: Option<StatusResponse>,
}Fields
request_id: u64code: i32message: Stringregister: Option<RegisterResponse>Payload fields — field numbers match RequestType enum values.
unregister: Option<UnregisterResponse>list_active: Option<ListActiveResponse>list_by_originator: Option<ListByOriginatorResponse>get_process_tree: Option<GetProcessTreeResponse>kill_zombies: Option<KillZombiesResponse>kill_tree: Option<KillTreeResponse>ping: Option<PingResponse>shutdown: Option<ShutdownResponse>status: Option<StatusResponse>Implementations
Sourceimpl DaemonResponse
impl DaemonResponse
Sourcepub fn code(&self) -> StatusCode
pub fn code(&self) -> StatusCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: StatusCode)
pub fn set_code(&mut self, value: StatusCode)
Sets code to the provided enum value.