pub struct ResizePtySessionRequest {
pub session_id: String,
pub rows: u32,
pub cols: u32,
}Expand description
Resize a PTY session without going through an attach. Useful for scripts that adjust the PTY dimensions between attaches, or for an orchestrator that wants to set the size once before any client connects. No-op on pipe sessions (no PTY to resize).
Fields
session_id: Stringrows: u32cols: u32Trait Implementations
Sourceimpl Clone for ResizePtySessionRequest
impl Clone for ResizePtySessionRequest
Sourcefn clone(&self) -> ResizePtySessionRequest
fn clone(&self) -> ResizePtySessionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResizePtySessionRequest
impl Debug for ResizePtySessionRequest
Sourceimpl Default for ResizePtySessionRequest
impl Default for ResizePtySessionRequest
Sourceimpl Hash for ResizePtySessionRequest
impl Hash for ResizePtySessionRequest
Sourceimpl Message for ResizePtySessionRequest
impl Message for ResizePtySessionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResizePtySessionRequest
impl PartialEq for ResizePtySessionRequest
Sourcefn eq(&self, other: &ResizePtySessionRequest) -> bool
fn eq(&self, other: &ResizePtySessionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResizePtySessionRequest
impl StructuralPartialEq for ResizePtySessionRequest